@@ -53,7 +53,8 @@ PIG__0_12_HADOOP_2 = "0.12-Hadoop-2"
 
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
-                         pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG):
+                         pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
+                         cluster_tags=[]):
     """
     Post a new job to a new cluster.
 
@@ -105,6 +106,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
             'git_ref': git_ref,
             'cluster_size': cluster_size,
             'cluster_type': cluster_type,
+            'cluster_tags': cluster_tags,
             'parameters': parameters or {},
             'notify_on_job_finish': notify_on_job_finish,
             'use_spot_instances': use_spot_instances,
