@@ -86,3 +86,11 @@ class TestJobs(unittest.TestCase):
         self.api_mock.get.return_value = response
         return_jobs = jobs.get_jobs(self.api_mock)
         self.assertEquals(return_jobs, response)
+
+    def test_post_spark_job_existing_cluster(self):
+        cluster_id = 'xyz123fdsa'
+        expected_job_id = 'abcdefghijklmnop'
+        self.api_mock.post.return_value = {'job_id': expected_job_id}
+        actual_job_id = jobs.post_job_existing_cluster(self.api_mock, self.project_name, self.script_name, cluster_id,
+            job_type=jobs.JOB_TYPE_SPARK_ON_JOBSERVER)
+        self.assertEquals(expected_job_id, actual_job_id)
